@@ -25,10 +25,11 @@ from zope.schema.fieldproperty import FieldProperty
 from pyams_alchemy.engine import get_user_session
 from pyams_alchemy.interfaces import IAlchemyConverter
 from pyams_alchemy.task.interfaces import IAlchemyTask
-from pyams_scheduler.interfaces.task import TASK_STATUS_EMPTY, TASK_STATUS_ERROR, TASK_STATUS_OK
+from pyams_scheduler.interfaces.task import TASK_STATUS_EMPTY, TASK_STATUS_FAIL, TASK_STATUS_OK
 from pyams_scheduler.task import Task
 from pyams_utils.factory import factory_config
 from pyams_utils.registry import get_utility
+from pyams_utils.text import render_text
 
 
 __docformat__ = 'restructuredtext'
@@ -50,28 +51,31 @@ class AlchemyTask(Task):
     def run(self, report, **kwargs):  # pylint: disable=unused-argument
         """Run SQL query task"""
         try:
-            session = get_user_session(self.session_name, join=False, twophase=False,
+            session = get_user_session(self.session_name,
+                                       join=False,
+                                       twophase=False,
                                        use_zope_extension=False)
             try:
+                query = render_text(self.query)
                 report.write('SQL query output\n'
                              '================\n')
                 report.write('SQL query: \n    {}\n\n'.format(
-                    self.query.replace('\r', '').replace('\n', '\n    ')))
-                results = session.execute(self.query)
+                    query.replace('\r', '').replace('\n', '\n    ')))
+                results = session.execute(query)
+                session.commit()
                 converter = get_utility(IAlchemyConverter, name=self.output_format)
                 result = converter.convert(results)
-                session.commit()
-                report.write('SQL output ({} records):\n\n'.format(results.rowcount))
+                report.write(f'SQL output ({results.rowcount} records):\n\n')
                 report.write(result)
                 return TASK_STATUS_OK, result
             except ResourceClosedError:
                 report.write('SQL query returned no result.\n')
                 return TASK_STATUS_EMPTY, None
         except SQLAlchemyError:
+            session.rollback()
             etype, value, tb = sys.exc_info()  # pylint: disable=invalid-name
             report.write('\n\n'
                          'An SQL error occurred\n'
                          '=====================\n')
             report.write(''.join(traceback.format_exception(etype, value, tb)))
-            session.abort()
-            return TASK_STATUS_ERROR, None
+            return TASK_STATUS_FAIL, None
