@@ -20,14 +20,14 @@ from zope.copy import copy
 from zope.interface import Interface, Invalid, implementer
 
 from pyams_alchemy.interfaces import IAlchemyEngineUtility, IAlchemyManager, \
-    MANAGE_SQL_ENGINES_PERMISSIONS
+    MANAGE_SQL_ENGINES_PERMISSION
 from pyams_alchemy.zmi import AlchemyManagerEnginesTable
 from pyams_form.ajax import ajax_form_config
 from pyams_form.field import Fields
 from pyams_form.interfaces import DISPLAY_MODE
 from pyams_form.interfaces.form import IAJAXFormRenderer, IAddForm, IDataExtractedEvent
 from pyams_layer.interfaces import IPyAMSLayer
-from pyams_skin.viewlet.actions import ContextAction
+from pyams_skin.viewlet.actions import ContextAddAction
 from pyams_table.interfaces import IColumn
 from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
 from pyams_utils.interfaces.intids import IUniqueID
@@ -63,21 +63,40 @@ def handle_new_engine_data_extraction(event):
                                                 "registered with this name!")),)
 
 
+@adapter_config(required=(IAlchemyManager, IAdminLayer, IAlchemyEngineAddForm),
+                provides=IAJAXFormRenderer)
+class AlchemyEngineAddFormRenderer(ContextRequestViewAdapter):
+    """Alchemy engine add form AJAX renderer"""
+
+    def render(self, changes):
+        """AJAX form renderer"""
+        if not changes:
+            return None
+        manager = get_parent(self.context, IAlchemyManager)
+        return {
+            'callbacks': [
+                get_json_table_row_add_callback(manager, self.request,
+                                                AlchemyManagerEnginesTable, changes)
+            ]
+        }
+
+
+#
+# Alchemy engine add form
+#
+
 @viewlet_config(name='add-sql-engine.menu',
                 context=IAlchemyManager, layer=IAdminLayer, view=AlchemyManagerEnginesTable,
                 manager=IToolbarViewletManager, weight=10,
-                permission=MANAGE_SQL_ENGINES_PERMISSIONS)
-class AlchemyEngineAddMenu(ContextAction):
-    """Alchemy engine add menu"""
+                permission=MANAGE_SQL_ENGINES_PERMISSION)
+class AlchemyEngineAddAction(ContextAddAction):
+    """Alchemy engine add action"""
 
-    status = 'success'
-    icon_class = 'fas fa-plus'
     label = _("Add SQL engine")
-
     href = 'add-sql-engine.html'
-    modal_target = True
 
 
+@implementer(IAlchemyEngineAddForm)
 class AlchemyEngineBaseAddFormMixin:
     """Alchemy engine base add form mixin"""
 
@@ -91,8 +110,7 @@ class AlchemyEngineBaseAddFormMixin:
 
 @ajax_form_config(name='add-sql-engine.html',
                   context=IAlchemyManager, layer=IPyAMSLayer,
-                  permission=MANAGE_SQL_ENGINES_PERMISSIONS)
-@implementer(IAlchemyEngineAddForm)
+                  permission=MANAGE_SQL_ENGINES_PERMISSION)
 class AlchemyEngineAddForm(AlchemyEngineBaseAddFormMixin, AdminModalAddForm):  # pylint: disable=abstract-method
     """SQLAlchemy engine add form"""
 
@@ -102,7 +120,7 @@ class AlchemyEngineAddForm(AlchemyEngineBaseAddFormMixin, AdminModalAddForm):  #
     content_factory = IAlchemyEngineUtility
 
     def add(self, obj):
-        oid = IUniqueID(obj)
+        oid = IUniqueID(obj).oid
         self.context[oid] = obj
 
 
@@ -126,8 +144,7 @@ class AlchemyEngineCloneColumn(ActionColumn):
 
 @ajax_form_config(name='clone-sql-engine.html',
                   context=IAlchemyEngineUtility, layer=IPyAMSLayer,
-                  permission=MANAGE_SQL_ENGINES_PERMISSIONS)
-@implementer(IAlchemyEngineAddForm)
+                  permission=MANAGE_SQL_ENGINES_PERMISSION)
 class AlchemyEngineCloneForm(AlchemyEngineBaseAddFormMixin, AdminModalAddForm):
     """SQLAlchemy engine clone form"""
 
@@ -143,24 +160,6 @@ class AlchemyEngineCloneForm(AlchemyEngineBaseAddFormMixin, AdminModalAddForm):
         self.context.__parent__[oid] = obj
 
 
-@adapter_config(required=(IAlchemyManager, IAdminLayer, IAlchemyEngineAddForm),
-                provides=IAJAXFormRenderer)
-class AlchemyEngineAddFormRenderer(ContextRequestViewAdapter):
-    """Alchemy engine add form AJAX renderer"""
-
-    def render(self, changes):
-        """AJAX form renderer"""
-        if not changes:
-            return None
-        manager = get_parent(self.context, IAlchemyManager)
-        return {
-            'callbacks': [
-                get_json_table_row_add_callback(manager, self.request,
-                                                AlchemyManagerEnginesTable, changes)
-            ]
-        }
-
-
 #
 # Alchemy engine edit form
 #
@@ -173,7 +172,7 @@ class AlchemyEngineElementEditor(TableElementEditor):
 
 @ajax_form_config(name='properties.html',
                   context=IAlchemyEngineUtility, layer=IPyAMSLayer,
-                  permission=MANAGE_SQL_ENGINES_PERMISSIONS)
+                  permission=MANAGE_SQL_ENGINES_PERMISSION)
 class AlchemyEngineEditForm(AdminModalEditForm):
     """SQLAlchemy engine properties edit form"""
 
